# Hierarchical Target Type Identification for Entity-oriented Queries

Note: all files are with Unix (LF) line endings and use \t as the field separator.

## Queries and annotations

### queries.txt
Queries from various benchmarking evaluation platforms in a single file (cf. Section 4.1). The queryID prefix denotes the source, `{X}` refers to the original queryID within the given benchmark.

  - `TREC_Entity-{X}`: 120 queries from the TREC 2009-2011 Entity track
  - `INEX-XER-{X}`: 55 queries from the INEX 2009 Entity Ranking track
  - `SemSearch_ES-{X}`: 142 queries from the entity search task of the 2010 and 2011 Semantic Search Challenge 
  - `SemSearch_LS-{X}`: 50 queries from the list search task of the 2011 Semantic Search Challenge 

### query-annotations.txt
High-level query annotations (cf. Table 1). For each queryID the annotation can be one of the followings (cf. Section 4.2):

  - `ST`: single type
  - `MT`: multiple types
  - `NC`: not covered
  - `NI`: not interpretable

All other files discussed below contain only queryIDs that are annotated with a single type (`ST`).

### query-types.txt
Target types for queries, taken from the DBpedia ontology, version 3.7. 
Format: `queryID type depth`, where depth denotes the type's level in the hierarchy (the root element, "Thing", is on level 0). Figure 1 in the paper shows the distribution of queries over hierarchical levels.

## Qrels
Various qrels files in TREC qrels format:

   - `toplevel.qrels`: binary judments for top-level types
   - `strict.qrels`: binary judgments (hierarchical case)
   - `lenient-linear.qrels`: lenient judments with linear decay
   - `lenient-exp.qrels`: lenient judments with exponential decay

Since `trec_eval` can only deal with integer relevance values, we use the values 1..6 for `lenient-linear.qrels` and 2^0..2^5 for `lenient-exp.qrels`. 

## Baselines
Type rankings using the type-centric and entity-centric models (in TREC runfile format).

   - `baseline-tc.run`, `baseline-ec.run`: run files for type-centric and entity-centric models, respectively (hierarchical case)
   - `baseline-toplevel-tc.run`, `baseline-toplevel-ec.run`: run files for type-centric and entity-centric models, respectively, considering only top-level types
   
Evaluating these files against the above qrels using [trec_eval](http://trec.nist.gov/trec_eval/) (version 9.0) should give you the same results that are reported in Tables 2 and 3. Specifically:

   - Table 2, columns 2-3: `baseline-toplevel-{tc|ec}.run` against `toplevel.qrels`
   - Table 2, columns 4-7: `baseline-{tc|ec}.run` against `strict.qrels`
   - Table 3, columns 2-3: `baseline-{tc|ec}.run` against `lenient-linear.qrels`
   - Table 3, columns 4-5: `baseline-{tc|ec}.run` against `lenient-exp.qrels`

Mind that `trec_eval` is used with default settings (apart from displaying S@1 and nDCG which are not shown by default), i.e., without the `-c` flag. This means that scores are computed for queries in the intersection of relevance judgements and results; we have results returned for 245 queries (i.e., 17 queries would have scored 0 on all metrics and these are not considered in the average), but this is the same for both the type-centric and entity-centric methods. 

## Reference
If using these resources, please cite our paper:
<pre>
@inproceedings{Balog:2012:HTT, 
	author = {Krisztian Balog and Robert Neumayer,
	title = {Hierarchical Target Type Identification for Entity-oriented Queries},
	booktitle = {21th ACM International Conference on Information and Knowledge Management (CIKM 2012)},
	publisher = {ACM},
	pages = {2391--2394},
	year = {2012}
}
</pre>

## Contact
In case of questions, feel free to contact us:

-  Krisztian Balog <Krisztian.Balog@idi.ntnu.no>
-  Robert Neumayer <Robert.Neumayer@idi.ntnu.no>
